AudioTag class

Constructors

AudioTag({String title = '', String artist = '', String album = '', String genre = '', String comment = '', int track = 0, int year = 0})
const

Properties

album String
final
artist String
final
comment String
final
genre String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final
track int
final
year int
final

Methods

copyWith({String? title, String? artist, String? album, String? genre, String? comment, int? track, int? year}) AudioTag
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited