than_audiotag_bindings_generated library

Classes

TagLib_AudioProperties
TagLib_Complex_Property_Attribute
! Attribute of a complex property. Complex properties consist of a NULL-terminated array of pointers to this structure with \e key and \e value.
TagLib_Complex_Property_Picture_Data
! Picture data extracted from a complex property by the convenience function taglib_picture_from_complex_property().
TagLib_File
These are used to give the C API some type safety (as opposed to using void * ), but pointers to them are simply cast to the corresponding C++ types in the implementation.
TagLib_IOStream
TagLib_Tag
TagLib_Variant
! Discriminated union used in complex property attributes.
ThanAudiotagBindings
Bindings for src/than_audiotag.h.
UnnamedUnion

Enums

TagLib_File_Type
File API
TagLib_ID3v2_Encoding
Special convenience ID3v2 functions
TagLib_Variant_Type
! Types which can be stored in a TagLib_Variant.