AudioProperties class
Constructors
- AudioProperties({int duration = 0, int bitrate = 0, int sampleRate = 0, int channels = 0})
-
const
Properties
- bitrate → int
-
Returns the bitrate of the file in kb/s.
final
- channels → int
-
Returns the number of channels in the audio stream.
final
- duration → int
-
Returns the length of the file in seconds.
final
- durationAsDuration → Duration
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleRate → int
-
Returns the sample rate of the file in Hz.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited